@@ -195,6 +195,12 @@ class Configuration(object):
                             ]
             self.lflags = None
 
+            # These confuse WAF, but since it already reliably picks the correct
+            # MSVC it shouldn't hurt to get rid of them.
+            for name in ['CC', 'CXX']:
+                if os.environ.get(name):
+                    os.environ.pop(name)
+
             # Other MSVC flags...
             # Uncomment these to have debug info for all kinds of builds
             #self.cflags += ['/Od', '/Z7']
@@ -570,6 +576,34 @@ class Configuration(object):
         return newLFLAGS
 
 
+    def checkSetup(self, build_dir, flag):
+        """
+        Find the setup.h generated by wxWidgets and return True if the given
+        flag (eg. "wxUSE_WEBKIT") is enabled.
+        """
+        def _find_setup():
+            for dirpath, dirnames, filenames in os.walk(build_dir):
+                for name in filenames:
+                    if name == 'setup.h':
+                        return opj(dirpath, name)
+            return None
+
+        setup = _find_setup()
+        with open(setup, 'rt') as f:
+            for line in f:
+                if flag in line:
+                    return '1' in line.split()
+        return False
+
+
+    def findWxConfigDir(self, wx_config):
+        output = runcmd(wx_config + " --cflags", getOutput=True, echoCmd=False)
+        # We expect that the first -I flag is the path we're looking for here
+        configDir = output.split()[0]
+        assert configDir.startswith('-I')
+        configDir = configDir[2:]
+        return configDir
+
 
 # We'll use a factory function so we can use the Configuration class as a singleton
 _config = None
